@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Data::OptList;
+package Data::OptList 0.114;
 # ABSTRACT: parse and validate simple name/value option pairs
-$Data::OptList::VERSION = '0.113';
+
 use List::Util ();
 use Params::Util ();
 use Sub::Install 0.921 ();
@@ -249,7 +249,7 @@ Data::OptList - parse and validate simple name/value option pairs
 
 =head1 VERSION
 
-version 0.113
+version 0.114
 
 =head1 SYNOPSIS
 
@@ -315,13 +315,13 @@ following a name is its value.
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 FUNCTIONS
 
